QuicError class sealed

Implemented types
Available extensions
Annotations
  • @freezed

Constructors

QuicError.config(String field0)
const
factory
QuicError.connection(String field0)
const
factory
QuicError.endpoint(String field0)
const
factory
QuicError.network(String field0)
const
factory
QuicError.stream(String field0)
const
factory
QuicError.tls(String field0)
const
factory
QuicError.write(String field0)
const
factory

Properties

copyWith → $QuicErrorCopyWith<QuicError>
Create a copy of QuicError with the given fields replaced by the non-null parameter values.
no setterinherited
field0 String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>({required TResult connection(QuicError_Connection value), required TResult endpoint(QuicError_Endpoint value), required TResult stream(QuicError_Stream value), required TResult tls(QuicError_Tls value), required TResult config(QuicError_Config value), required TResult network(QuicError_Network value), required TResult write(QuicError_Write value)}) → TResult

Available on QuicError, provided by the QuicErrorPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>({TResult? connection(QuicError_Connection value)?, TResult? endpoint(QuicError_Endpoint value)?, TResult? stream(QuicError_Stream value)?, TResult? tls(QuicError_Tls value)?, TResult? config(QuicError_Config value)?, TResult? network(QuicError_Network value)?, TResult? write(QuicError_Write value)?}) → TResult?

Available on QuicError, provided by the QuicErrorPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>({TResult connection(QuicError_Connection value)?, TResult endpoint(QuicError_Endpoint value)?, TResult stream(QuicError_Stream value)?, TResult tls(QuicError_Tls value)?, TResult config(QuicError_Config value)?, TResult network(QuicError_Network value)?, TResult write(QuicError_Write value)?, required TResult orElse()}) → TResult

Available on QuicError, provided by the QuicErrorPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>({TResult connection(String field0)?, TResult endpoint(String field0)?, TResult stream(String field0)?, TResult tls(String field0)?, TResult config(String field0)?, TResult network(String field0)?, TResult write(String field0)?, required TResult orElse()}) → TResult

Available on QuicError, provided by the QuicErrorPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>({required TResult connection(String field0), required TResult endpoint(String field0), required TResult stream(String field0), required TResult tls(String field0), required TResult config(String field0), required TResult network(String field0), required TResult write(String field0)}) → TResult

Available on QuicError, provided by the QuicErrorPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>({TResult? connection(String field0)?, TResult? endpoint(String field0)?, TResult? stream(String field0)?, TResult? tls(String field0)?, TResult? config(String field0)?, TResult? network(String field0)?, TResult? write(String field0)?}) → TResult?

Available on QuicError, provided by the QuicErrorPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited